<?php
/**
 * The template for displaying comments
 *
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package yuno
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}
?>
<div id="comments" class="comments-area">
	<?php
	// You can start editing here -- including this comment!
	if ( have_comments() ) :
		?>
		<h2 class="comments-title">
			<?php
			$yuno_comment_count = get_comments_number();
			if ( '1' === $yuno_comment_count ) {
				printf(
					/* translators: 1: title. */
					esc_html__( 'One thought on &ldquo;%1$s&rdquo;', 'yuno' ),
					'<span>' . wp_kses_post( get_the_title() ) . '</span>'
				);
			} else {
				printf( 
					/* translators: 1: comment count number, 2: title. */
					esc_html( _nx( '%1$s thought on &ldquo;%2$s&rdquo;', '%1$s thoughts on &ldquo;%2$s&rdquo;', $yuno_comment_count, 'comments title', 'yuno' ) ),
					number_format_i18n( $yuno_comment_count ), // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					'<span>' . wp_kses_post( get_the_title() ) . '</span>'
				);
			}
			?>
		</h2><!-- .comments-title -->
		<?php the_comments_navigation(); ?>
		<ol class="comment-list">
			<?php
			wp_list_comments(
				array(
					'avatar_size' => 60,
					'style'       => 'ol',
					'short_ping'  => true,
				)
			);
			?>
		</ol><!-- .comment-list -->
		<?php
		the_comments_navigation();

		// If comments are closed and there are comments, let's leave a little note, shall we?
		if ( ! comments_open() ) :
			?>
			<p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'yuno' ); ?></p>
			<?php
		endif;

	endif; // Check for have_comments().

	$comments_args = array(
        'label_submit'        => esc_html__( 'Post Comment', 'yuno' ),
        'title_reply'         => esc_html__( 'Leave a Comment', 'yuno' ),
        'submit_button'       => '<input name="%1$s" type="submit" id="%2$s" class="%3$s btn btn-primary btn-sm" value="%4$s" />',   
        'comment_notes_after' => '',
        'comment_field'       => '<div class="col-lg-12 mb-4">
              <textarea class="form-control" rows="5" id="comment" name="comment" aria-required="true" placeholder="' . esc_html__( 'Your Comment', 'yuno' ) . '"></textarea>
            </div>',
	);
	comment_form( $comments_args );
	?>
</div><!-- #comments -->