<?php
/**
 * yuno functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package yuno
 */

if ( ! defined( 'yuno_THEME_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( 'yuno_THEME_VERSION', '1.0.2' );
}

if ( ! function_exists( 'yuno_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function yuno_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 */
		load_theme_textdomain( 'yuno' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'yuno_primary_menu' => esc_html__( 'Primary', 'yuno' ),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		$args = array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			);
		add_theme_support( 'html5', $args );

		// Set up the WordPress core custom background feature.
		$args = array(
			'default-color' => 'ffffff',
			'default-image' => '',
		);
		add_theme_support( "custom-background", $args );

		$args = array(
	        'default-image'      => '%s/assets/images/header-image-2.jpg',
	        'default-text-color' => 'fff',
	       	'width'              => 1900, /* 16:9 Aspect Ratio */
			'height'             => 441,
	        'flex-width'         => true,
	        'flex-height'        => true
	    );
		add_theme_support( "custom-header", $args );

		register_default_headers( 
			array(
				'banner-1' => array(
					'url'           => '%s/assets/images/header-image.jpg',
					'thumbnail_url' => '%s/assets/images/header-image.jpg',
					'description'   => '',
				),
				'banner-2' => array(
					'url'           => '%s/assets/images/header-image-1.jpg',
					'thumbnail_url' => '%s/assets/images/header-image-1.jpg',
					'description'   => '',
				),
				'banner-3' => array(
					'url'           => '%s/assets/images/header-image-2.jpg',
					'thumbnail_url' => '%s/assets/images/header-image-2.jpg',
					'description'   => '',
				),
				'banner-4' => array(
					'url'           => '%s/assets/images/header-image-3.jpg',
					'thumbnail_url' => '%s/assets/images/header-image-3.jpg',
					'description'   => '',
				),
				'banner-5' => array(
					'url'           => '%s/assets/images/header-image-4.jpg',
					'thumbnail_url' => '%s/assets/images/header-image-4.jpg',
					'description'   => '',
				),
			) 
		);
        
		// Add support for Block Styles.
		add_theme_support( 'wp-block-styles' );

        // Add support for full and wide align images.
		add_theme_support( 'align-wide' );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/* Allow shortcodes in widgets. */
        add_filter( 'widget_text', 'do_shortcode' );

        // Add custom editor font sizes.
		add_theme_support(
			'editor-font-sizes',
			array(
				array(
					'name'      => esc_html__( 'Extra small', 'yuno' ),
					'shortName' => esc_html_x( 'XS', 'Font size', 'yuno' ),
					'size'      => 16,
					'slug'      => 'extra-small',
				),
				array(
					'name'      => esc_html__( 'Small', 'yuno' ),
					'shortName' => esc_html_x( 'S', 'Font size', 'yuno' ),
					'size'      => 18,
					'slug'      => 'small',
				),
				array(
					'name'      => esc_html__( 'Normal', 'yuno' ),
					'shortName' => esc_html_x( 'M', 'Font size', 'yuno' ),
					'size'      => 20,
					'slug'      => 'normal',
				),
				array(
					'name'      => esc_html__( 'Large', 'yuno' ),
					'shortName' => esc_html_x( 'L', 'Font size', 'yuno' ),
					'size'      => 24,
					'slug'      => 'large',
				),
				array(
					'name'      => esc_html__( 'Extra large', 'yuno' ),
					'shortName' => esc_html_x( 'XL', 'Font size', 'yuno' ),
					'size'      => 40,
					'slug'      => 'extra-large',
				),
				array(
					'name'      => esc_html__( 'Huge', 'yuno' ),
					'shortName' => esc_html_x( 'XXL', 'Font size', 'yuno' ),
					'size'      => 96,
					'slug'      => 'huge',
				),
				array(
					'name'      => esc_html__( 'Gigantic', 'yuno' ),
					'shortName' => esc_html_x( 'XXXL', 'Font size', 'yuno' ),
					'size'      => 144,
					'slug'      => 'gigantic',
				),
			)
		);

        // Editor color palette.
		$black     = '#000000';
		$dark_gray = '#28303D';
		$gray      = '#39414D';
		$green     = '#D1E4DD';
		$blue      = '#D1DFE4';
		$purple    = '#D1D1E4';
		$red       = '#E4D1D1';
		$orange    = '#E4DAD1';
		$yellow    = '#EEEADD';
		$white     = '#FFFFFF';

		add_theme_support(
			'editor-color-palette',
			array(
				array(
					'name'  => esc_html__( 'Black', 'yuno' ),
					'slug'  => 'black',
					'color' => $black,
				),
				array(
					'name'  => esc_html__( 'Dark gray', 'yuno' ),
					'slug'  => 'dark-gray',
					'color' => $dark_gray,
				),
				array(
					'name'  => esc_html__( 'Gray', 'yuno' ),
					'slug'  => 'gray',
					'color' => $gray,
				),
				array(
					'name'  => esc_html__( 'Green', 'yuno' ),
					'slug'  => 'green',
					'color' => $green,
				),
				array(
					'name'  => esc_html__( 'Blue', 'yuno' ),
					'slug'  => 'blue',
					'color' => $blue,
				),
				array(
					'name'  => esc_html__( 'Purple', 'yuno' ),
					'slug'  => 'purple',
					'color' => $purple,
				),
				array(
					'name'  => esc_html__( 'Red', 'yuno' ),
					'slug'  => 'red',
					'color' => $red,
				),
				array(
					'name'  => esc_html__( 'Orange', 'yuno' ),
					'slug'  => 'orange',
					'color' => $orange,
				),
				array(
					'name'  => esc_html__( 'Yellow', 'yuno' ),
					'slug'  => 'yellow',
					'color' => $yellow,
				),
				array(
					'name'  => esc_html__( 'White', 'yuno' ),
					'slug'  => 'white',
					'color' => $white,
				),
			)
		);

		add_theme_support(
			'editor-gradient-presets',
			array(
				array(
					'name'     => esc_html__( 'Purple to yellow', 'yuno' ),
					'gradient' => 'linear-gradient(160deg, ' . $purple . ' 0%, ' . $yellow . ' 100%)',
					'slug'     => 'purple-to-yellow',
				),
				array(
					'name'     => esc_html__( 'Yellow to purple', 'yuno' ),
					'gradient' => 'linear-gradient(160deg, ' . $yellow . ' 0%, ' . $purple . ' 100%)',
					'slug'     => 'yellow-to-purple',
				),
				array(
					'name'     => esc_html__( 'Green to yellow', 'yuno' ),
					'gradient' => 'linear-gradient(160deg, ' . $green . ' 0%, ' . $yellow . ' 100%)',
					'slug'     => 'green-to-yellow',
				),
				array(
					'name'     => esc_html__( 'Yellow to green', 'yuno' ),
					'gradient' => 'linear-gradient(160deg, ' . $yellow . ' 0%, ' . $green . ' 100%)',
					'slug'     => 'yellow-to-green',
				),
				array(
					'name'     => esc_html__( 'Red to yellow', 'yuno' ),
					'gradient' => 'linear-gradient(160deg, ' . $red . ' 0%, ' . $yellow . ' 100%)',
					'slug'     => 'red-to-yellow',
				),
				array(
					'name'     => esc_html__( 'Yellow to red', 'yuno' ),
					'gradient' => 'linear-gradient(160deg, ' . $yellow . ' 0%, ' . $red . ' 100%)',
					'slug'     => 'yellow-to-red',
				),
				array(
					'name'     => esc_html__( 'Purple to red', 'yuno' ),
					'gradient' => 'linear-gradient(160deg, ' . $purple . ' 0%, ' . $red . ' 100%)',
					'slug'     => 'purple-to-red',
				),
				array(
					'name'     => esc_html__( 'Red to purple', 'yuno' ),
					'gradient' => 'linear-gradient(160deg, ' . $red . ' 0%, ' . $purple . ' 100%)',
					'slug'     => 'red-to-purple',
				),
			)
		);

		// Add support for responsive embedded content.
		add_theme_support( 'responsive-embeds' );

		// Add support for custom line height controls.
		add_theme_support( 'custom-line-height' );

		// Add support for experimental link color control.
		add_theme_support( 'experimental-link-color' );

		// Add support for experimental cover block spacing.
		add_theme_support( 'custom-spacing' );

		// Add support for custom units.
		// This was removed in WordPress 5.6 but is still required to properly support WP 5.5.
		add_theme_support( 'custom-units' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		$args = array(
				'width'       => 220,
            	'height'      => 64,
            	'flex-width'  => true,
				'flex-height' => true,
			);
		add_theme_support( 'custom-logo', $args );

		/*
    	 * This theme styles the visual editor to resemble the theme style,
    	 * specifically font, colors, and column width.
     	 */
    	add_editor_style( array( 'assets/css/editor-style.css', yuno_fonts_url() ) );

		// Add support for editor styles.
        add_theme_support( 'editor-styles' );

		/*
         * For WooCommerce Product images
         */
        add_theme_support( 'wc-product-gallery-zoom' );
        add_theme_support( 'wc-product-gallery-lightbox' );
        add_theme_support( 'wc-product-gallery-slider' );
        
	}
endif;
add_action( 'after_setup_theme', 'yuno_setup' );

function yuno_social_icon_defaults() {
	$icons_data = json_decode( get_theme_mod( 'yuno_social_media_icons' ) );
	if ( empty( $icons_data ) ) {
		$main_social_icons_data = json_encode( array(
			array(
                'social_icon_class' => 'fab fa-facebook-f',
	            'social_icon_url'   => '#',
            ),
			array(
                'social_icon_class' => 'fab fa-twitter',
	            'social_icon_url'   => '#',
            ),
            array(
                'social_icon_class' => 'fab fa-instagram',
	            'social_icon_url'   => '#',
            ),
            array(
                'social_icon_class' => 'fab fa-linkedin',
	            'social_icon_url'   => '#',
            ),
		) );
		set_theme_mod( 'yuno_social_media_icons', $main_social_icons_data );
	}
}
add_action( 'after_setup_theme', 'yuno_social_icon_defaults' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function yuno_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'yuno_content_width', 640 );
}
add_action( 'after_setup_theme', 'yuno_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function yuno_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'yuno' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'yuno' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar( array(
		'name'          => esc_html__( 'Footer 1', 'yuno' ),
		'id'            => 'footer-widgets',
		'description'   => esc_html__( 'Add widgets here.', 'yuno' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 2', 'yuno' ),
		'id'            => 'footer-widgets-2',
		'description'   => esc_html__( 'Add widgets here.', 'yuno' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 3', 'yuno' ),
		'id'            => 'footer-widgets-3',
		'description'   => esc_html__( 'Add widgets here.', 'yuno' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 4', 'yuno' ),
		'id'            => 'footer-widgets-4',
		'description'   => esc_html__( 'Add widgets here.', 'yuno' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
}
add_action( 'widgets_init', 'yuno_widgets_init' );

/**
 * Register custom fonts.
 */
function yuno_fonts_url() {
	$fonts_url = '';

	$font_families = array();
	
	/*
	 * Translators: If there are characters in your language that are not
	 * supported by Montserrat, translate this to 'off'. Do not translate
	 * into your own language.
	 */

	$RobotoS = _x( 'on', 'Roboto+Slab font: on or off', 'yuno' );

	if ( 'off' !== $RobotoS ) {
		$font_families[] = 'Roboto+Slab:100,200,300,400,500,600,700,800,900';
	}

	$Roboto = _x( 'on', 'Roboto font: on or off', 'yuno' );

	if ( 'off' !== $Roboto ) {
		$font_families[] = 'Roboto:100,300,400,500,700';
	}

	$query_args = array(
		'family' => urlencode( implode( '|', $font_families ) ),
		'subset' => urlencode( 'latin,latin-ext' ),
	);

	$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );

	return esc_url_raw( $fonts_url );
}

/**
 * Enqueue editor styles for Gutenberg
 *
 * @since yuno 1.0.0
 */
function yuno_block_editor_styles() {
	// Block styles.
	wp_enqueue_style( 'yuno-block-editor-style', get_theme_file_uri( '/assets/css/editor-blocks.css' ) );
	// Add custom fonts.
	wp_enqueue_style( 'yuno-fonts', yuno_fonts_url(), array(), null );
}
add_action( 'enqueue_block_editor_assets', 'yuno_block_editor_styles' );

/**
 * Custom helper functions for this theme.
 */
require get_template_directory() . '/inc/helpers/helpers.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Custom Hooks
 */
require get_template_directory() . '/inc/hooks/header-hooks.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';
require get_template_directory() . '/inc/classes/class-bootstrap-nav-walker.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

require get_template_directory() . '/inc/admin/theme-activation-notice.php';

/** WooCommerce Compatibility File **/
require get_template_directory() . '/inc/woocommerce.php';



















