<?php
/**
 * Yuno General Settings panel at Theme Customizer
 *
 * @package Yuno
 * @since 1.0.0
 */

add_action( 'customize_register', 'yuno_general_settings_register' );

function yuno_general_settings_register( $wp_customize ) {

    // Register the radio image control class as a JS control type.
    $wp_customize->register_control_type( 'yuno_Customize_Image_Radio_Control' );
    $wp_customize->register_control_type( 'yuno_Customizer_Heading' );

    $wp_customize->get_section( 'title_tagline' )->panel        = 'yuno_general_settings_panel';
    $wp_customize->get_section( 'title_tagline' )->priority     = '5';
    $wp_customize->get_section( 'colors' )->panel               = 'yuno_general_settings_panel';
    $wp_customize->get_section( 'colors' )->priority            = '10';
    $wp_customize->get_section( 'background_image' )->panel     = 'yuno_general_settings_panel';
    $wp_customize->get_section( 'background_image' )->priority  = '15';
    $wp_customize->get_section( 'header_image' )->panel         = 'yuno_general_settings_panel';
    $wp_customize->get_section( 'header_image' )->priority      = '20';
    $wp_customize->get_section( 'static_front_page' )->panel    = 'yuno_general_settings_panel';
    $wp_customize->get_section( 'static_front_page' )->priority = '25';

    /**
     * Add Appearance Settings Panel
     *
     * @since 1.0.0
     */
    $wp_customize->add_panel(
        'yuno_general_settings_panel',
        array(
            'priority'       => 5,
            'capability'     => 'edit_theme_options',
            'theme_supports' => '',
            'title'          => esc_html__( 'General Settings', 'yuno' ),
        )
    );

/*-----------------------------------------------------------------------------------------------------------------------*/

    /**
     * Color option for theme
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_theme_color',
        array(
            'default'           => '#FF0066',
            'sanitize_callback' => 'sanitize_hex_color',
        )
    ); 
    $wp_customize->add_control( new WP_Customize_Color_Control(
            $wp_customize,
            'yuno_theme_color',
            array(
                'label'    => esc_html__( 'Theme Color', 'yuno' ),
                'section'  => 'colors',
                'priority' => 5
            )
        )
    );

/*-----------------------------------------------------------------------------------------------------------------------*/

    /**
     * Color option for Links
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_link_color',
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_hex_color',
        )
    ); 
    $wp_customize->add_control( new WP_Customize_Color_Control(
            $wp_customize,
            'yuno_link_color',
            array(
                'label'    => esc_html__( 'Link Color', 'yuno' ),
                'section'  => 'colors',
                'priority' => 5
            )
        )
    );

/*-----------------------------------------------------------------------------------------------------------------------*/

    /**
     * Color option for buttons
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_btn_color',
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_hex_color',
        )
    ); 
    $wp_customize->add_control( new WP_Customize_Color_Control(
            $wp_customize,
            'yuno_btn_color',
            array(
                'label'    => esc_html__( 'Button Color', 'yuno' ),
                'section'  => 'colors',
                'priority' => 5
            )
        )
    );

/*-----------------------------------------------------------------------------------------------------------------------*/

    /**
     * Color option for button border
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_btn_border_color',
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_hex_color',
        )
    ); 
    $wp_customize->add_control( new WP_Customize_Color_Control(
            $wp_customize,
            'yuno_btn_border_color',
            array(
                'label'    => esc_html__( 'Button Border Color', 'yuno' ),
                'section'  => 'colors',
                'priority' => 5
            )
        )
    );

/*-----------------------------------------------------------------------------------------------------------------------*/

    /**
     * Color option for button Hover
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_btn_hover_color',
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_hex_color',
        )
    ); 
    $wp_customize->add_control( new WP_Customize_Color_Control(
            $wp_customize,
            'yuno_btn_hover_color',
            array(
                'label'    => esc_html__( 'Button Hover Color', 'yuno' ),
                'section'  => 'colors',
                'priority' => 5
            )
        )
    );

/*-----------------------------------------------------------------------------------------------------------------------*/

    /**
     * Color option for button Hover border
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_btn_hover_border_color',
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_hex_color',
        )
    ); 
    $wp_customize->add_control( new WP_Customize_Color_Control(
            $wp_customize,
            'yuno_btn_hover_border_color',
            array(
                'label'    => esc_html__( 'Button Border Color on Hover', 'yuno' ),
                'section'  => 'colors',
                'priority' => 5
            )
        )
    );

    /*-----------------------------------------------------------------------------------------------------------------------*/
    /**
     * Website layout section
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'yuno_website_layout_section',
        array(
            'title'       => esc_html__( 'Website Layout', 'yuno' ),
            'description' => esc_html__( 'Choose a layout to display your website more effectively.', 'yuno' ),
            'priority'    => 55,
            'panel'       => 'yuno_general_settings_panel',
        )
    );

    /**
     * Site layout
     */
    $wp_customize->add_setting(
        'yuno_site_layout',
        array(
            'default'           => 'fullwidth_layout',
            'sanitize_callback' => 'sanitize_key',
        )       
    );
    $wp_customize->add_control(
        new yuno_Customize_Image_Radio_Control(
            $wp_customize,
            'yuno_site_layout',
            array(
                'type'     => 'yuno-radio-image',
                'label'    => esc_html__( 'Site Layout', 'yuno' ),
                'section'  => 'yuno_website_layout_section',
                'choices'  => array(
                    'fullwidth_layout' => array(
                        'label' => esc_html__( 'Full width layout', 'yuno' ),
                        'url'   => '%s/assets/images/customizer/full-1.png'
                    ),
                    'boxed_layout' => array(
                        'label' => esc_html__( 'Boxed layout', 'yuno' ),
                        'url'   => '%s/assets/images/customizer/full.png'
                    ),
                    'frame_layout' => array(
                        'label' => esc_html__( 'Frame layout', 'yuno' ),
                        'url'   => '%s/assets/images/customizer/full.png'
                    )
                ),
                'priority' => 5,
            )
        )
    );

    /**
     * page sidebar layout
     */
    $wp_customize->add_setting(
        'yuno_page_sidebar_layout',
        array(
            'default'           => 'right_sidebar',
            'sanitize_callback' => 'sanitize_key',
        )       
    );
    $wp_customize->add_control(
        new yuno_Customize_Image_Radio_Control(
            $wp_customize,
            'yuno_page_sidebar_layout',
            array(
                'type'     => 'yuno-radio-image',
                'label'    => esc_html__( 'Page Sidebar Layout', 'yuno' ),
                'section'  => 'yuno_website_layout_section',
                'choices'  => array(
                    'no_sidebar' => array(
                        'label'    => esc_html__( 'Full width layout', 'yuno' ),
                        'url'      => '%s/assets/images/customizer/full.png'
                    ),
                    'left_sidebar' => array(
                        'label'    => esc_html__( 'Left Sidebar', 'yuno' ),
                        'url'      => '%s/assets/images/customizer/left.png'
                    ),
                    'right_sidebar' => array(
                        'label'     => esc_html__( 'Right Sidebar', 'yuno' ),
                        'url'       => '%s/assets/images/customizer/right.png'
                    )
                ),
                'priority' => 5,
            )
        )
    );

    /**
     * Blog sidebar layout
     */
    $wp_customize->add_setting(
        'yuno_blog_sidebar_layout',
        array(
            'default'           => 'right_sidebar',
            'sanitize_callback' => 'sanitize_key',
        )       
    );
    $wp_customize->add_control(
        new yuno_Customize_Image_Radio_Control(
            $wp_customize,
            'yuno_blog_sidebar_layout',
            array(
                'type'     => 'yuno-radio-image',
                'label'    => esc_html__( 'Archive Sidebar Layout', 'yuno' ),
                'section'  => 'yuno_website_layout_section',
                'choices'  => array(
                    'no_sidebar' => array(
                        'label'    => esc_html__( 'Full-width layout', 'yuno' ),
                        'url'      => '%s/assets/images/customizer/full.png'
                    ),
                    'left_sidebar' => array(
                        'label'    => esc_html__( 'Left Sidebar', 'yuno' ),
                        'url'      => '%s/assets/images/customizer/left.png'
                    ),
                    'right_sidebar' => array(
                        'label'     => esc_html__( 'Right Sidebar', 'yuno' ),
                        'url'       => '%s/assets/images/customizer/right.png'
                    )
                ),
                'priority' => 5,
            )
        )
    );

    /**
     * Post( Single-page ) sidebar layout
     */
    $wp_customize->add_setting(
        'yuno_single_sidebar_layout',
        array(
            'default'           => 'right_sidebar',
            'sanitize_callback' => 'sanitize_key',
        )       
    );
    $wp_customize->add_control(
        new yuno_Customize_Image_Radio_Control(
            $wp_customize,
            'yuno_single_sidebar_layout',
            array(
                'type'     => 'yuno-radio-image',
                'label'    => esc_html__( 'Post( Single-page ) sidebar Layout', 'yuno' ),
                'section'  => 'yuno_website_layout_section',
                'choices'  => array(
                    'no_sidebar' => array(
                        'label'    => esc_html__( 'Full-width layout', 'yuno' ),
                        'url'      => '%s/assets/images/customizer/full.png'
                    ),
                    'left_sidebar' => array(
                        'label'    => esc_html__( 'Left Sidebar', 'yuno' ),
                        'url'      => '%s/assets/images/customizer/left.png'
                    ),
                    'right_sidebar' => array(
                        'label'     => esc_html__( 'Right Sidebar', 'yuno' ),
                        'url'       => '%s/assets/images/customizer/right.png'
                    )
                ),
                'priority' => 5,
            )
        )
    );

    /**
     * Scroll to top
     */
    $wp_customize->add_setting(
        'yuno_scroll_to_top',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'yuno_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new yuno_Customize_Switch_Control(
        $wp_customize,
        'yuno_scroll_to_top',
            array(
                'type'        => 'yuno-switch',
                'label'       => esc_html__( 'Scroll to top', 'yuno' ),
                'description' => esc_html__( 'Show/Hide option for scroll to top icon in bottom', 'yuno' ),
                'section'     => 'yuno_website_layout_section',
                'choices'     => array(
                    'show' => esc_html__( 'Show', 'yuno' ),
                    'hide' => esc_html__( 'Hide', 'yuno' ),
                ),
                'priority'    => 10,
            )
        )
    );

    /**
     * Switch option for page loader
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_pageloader',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'yuno_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new yuno_Customize_Switch_Control(
        $wp_customize,
        'yuno_pageloader',
        array(
            'type'        => 'yuno-switch',
            'label'       => esc_html__( 'Page loader', 'yuno' ),
            'description' => esc_html__( 'Show/Hide option for page loader.', 'yuno' ),
            'section'     => 'yuno_website_layout_section',
            'choices'     => array(
                'show' => esc_html__( 'Show', 'yuno' ),
                'hide' => esc_html__( 'Hide', 'yuno' ),
            ),
            'priority'    => 10,
        )
    )
    );

}