<?php

/**
 * Custom hooks functions are define about header section.
 *
 * @package Yuno
 * @since 1.0.0
 */

/*-----------------------------------------------------------------------------------------------------------------------*/

if (!function_exists('yuno_top_bar_start')) :

    /**
     * Top bar start
     *
     * @since 1.0.0
     */

    function yuno_top_bar_start()
    {
        if (get_theme_mod('yuno_top_bar_switch', 'show') == 'show') {
?>
            <div class="contact-infobar">
                <div class="container content-center">
                    <?php
                }
            }

        endif;

        /*-----------------------------------------------------------------------------------------------------------------------*/

        if (!function_exists('yuno_top_bar_social_icons')) :

            /**
             * Top bar social icons
             *
             * @since 1.0.0
             */

            function yuno_top_bar_social_icons()
            {
                if (get_theme_mod('yuno_top_bar_switch', 'show') == 'show') {
                    if (get_theme_mod('yuno_social_icons_switch', 'show') == 'show') {
                    ?>
                        <ul class="nav social-media">
                            <?php
                            if (!empty(get_theme_mod('yuno_social_media_icons'))) {
                                $social_icons = json_decode(get_theme_mod('yuno_social_media_icons'));
                                foreach ($social_icons as $key => $value) {
                                    $array = array();
                                    foreach ($value as $key) {
                                        $array[] = $key;
                                    }
                                    if (!empty($array)) {
                                        echo '<li class="nav-item"><a href="' . esc_attr(esc_url($array[1])) . '" class="nav-link" data-bs-toggle="tooltip"><i class="' . esc_attr($array[0]) . '"></i></a></li>';
                                    }
                                }
                            }
                            ?>
                        </ul>
                    <?php
                    }
                }
            }

        endif;

        /*-----------------------------------------------------------------------------------------------------------------------*/

        if (!function_exists('yuno_top_bar_contact_details')) :

            /**
             * Topbar contact details
             *
             * @since 1.0.0
             */

            function yuno_top_bar_contact_details()
            {
                $yuno_phone_number  = get_theme_mod('yuno_phone_number', '+123-456-7890');
                $yuno_email_address = get_theme_mod('yuno_email_address', 'info@example.com');

                if (get_theme_mod('yuno_top_bar_switch', 'show') == 'show') {
                    ?>
                    <ul class="nav contact-group">
                        <li class="contact-list"><i class="fa fa-phone" aria-hidden="true"></i> <span> <?php echo esc_html($yuno_phone_number); ?> </span></li>
                        <li class="contact-list"><i class="fa fa-envelope" aria-hidden="true"></i> <span> <?php echo esc_html($yuno_email_address); ?> </span> </li>
                    </ul>
                <?php
                }
            }

        endif;

        /*-----------------------------------------------------------------------------------------------------------------------*/

        if (!function_exists('yuno_top_bar_end')) :

            /**
             * Top header bar end
             *
             * @since 1.0.0
             */

            function yuno_top_bar_end()
            {
                if (get_theme_mod('yuno_top_bar_switch', 'show') == 'show') {
                ?>
                </div>
            </div>
        <?php
                }
            }

        endif;

        /*-----------------------------------------------------------------------------------------------------------------------*/

        /**
         * Managed functions for header top bar section hook
         *
         * @since 1.0.0
         */
        add_action('yuno_header_top_bar', 'yuno_top_bar_start', 5);
        add_action('yuno_header_top_bar', 'yuno_top_bar_social_icons', 10);
        add_action('yuno_header_top_bar', 'yuno_top_bar_contact_details', 15);
        add_action('yuno_header_top_bar', 'yuno_top_bar_end', 20);

        /*-----------------------------------------------------------------------------------------------------------------------*/

        if (!function_exists('yuno_top_header_start')) :

            /**
             * Top header start
             *
             * @since 1.0.0
             */

            function yuno_top_header_start()
            {
        ?>
        <nav id="site-navigation" class="navbar navbar-expand-lg main-navigation navbar">
            <div class="container">
            <?php
            }

        endif;

        /*-----------------------------------------------------------------------------------------------------------------------*/

        if (!function_exists('yuno_site_branding')) :

            /**
             * header navbar left section
             *
             * @since 1.0.0
             */

            function yuno_site_branding()
            {
            ?>
                <!-- .site-branding -->
                <div class="site-branding">
                    <?php if (has_custom_logo()) { ?>

                        <?php the_custom_logo(); ?>
                        <!-- .site-logo -->
                        <?php }
                    if (display_header_text()) {
                        if (get_bloginfo()) {
                        ?>
                            <h3 class="site-title"><a href="<?php echo esc_url(home_url('/')); ?>" title="<?php the_title_attribute(); ?>" rel="<?php echo esc_attr(get_bloginfo('name')); ?>"><?php bloginfo('name'); ?></a></h3>
                        <?php }
                        $description = get_bloginfo('description', 'display');
                        if ($description || is_customize_preview()) { ?>
                            <p class="site-description"><?php echo esc_html($description); ?></p>
                    <?php
                        }
                    }
                    ?>
                </div><!-- .site-branding -->
            <?php
            }

        endif;

        /*-----------------------------------------------------------------------------------------------------------------------*/

        if (!function_exists('yuno_header_nav_menu')) :

            /**
             * header navbar left section
             *
             * @since 1.0.0
             */

            function yuno_header_nav_menu()
            {
            ?>
                <button class="navbar-toggler menu-toggle menu-toggle-2" type="button" data-bs-toggle="collapse" data-bs-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="<?php esc_attr('Toggle navigation', 'yuno'); ?>">
                    <span> <i class="fas fa-bars"></i> </span>
                </button>
                <div class="collapse navbar-collapse text-center" id="navbarSupportedContent">
                    <button class="tab-focus_1 tab-hiddn-btn"></button>
                    <?php
                    wp_nav_menu(array(
                        'theme_location' => 'yuno_primary_menu',
                        'menu_id'        => 'primary-menu',
                        'depth'          => 4,
                        'container'      => false,
                        'menu_class'     => 'navbar-nav m-auto',
                        'fallback_cb'    => 'yuno_menu_fallback_cb',
                        'walker'         => new yuno_bootstrap_Navwalker()
                    ));
                    ?>
                    <button class="navbar-toggler menu-toggle menu_mobile_close_btn" type="button" data-bs-toggle="collapse" data-bs-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="<?php esc_attr('Toggle navigation', 'yuno'); ?>">
                        <span> <i class="fas fa-times"></i> </span>
                    </button>
                    <button class="tab-focus_3 tab-hiddn-btn"></button>
                </div>
            <?php
            }

        endif;

        /*-----------------------------------------------------------------------------------------------------------------------*/

        if (!function_exists('yuno_header_search_box')) :

            /**
             * header navbar end
             *
             * @since 1.0.0
             */

            function yuno_header_search_box()
            {
            ?>


                <?php if (class_exists('woocommerce')) { ?>
                    <?php if (!is_cart()) : ?>

                        <!----woocart---->


                        <div class="mini_cart_btn">
                            <a href="#" class="js-menu__open nav-link" data-menu="#main-nav"><i class="<?php echo esc_attr(get_theme_mod('vw_ecommerce_store_cart_icon', 'fas fa-shopping-basket')); ?>"></i><span class="screen-reader-text"><?php esc_html_e('shopping cart', 'yuno'); ?></span></a>
                            <span class="cart-value"> <?php echo wp_kses_data(WC()->cart->get_cart_contents_count()); ?></span>
                        </div>
                        <div class="js-menu__context">
                            <div id="main-nav" class="js-menu js-menu--right">

                                <div class="mini_cart_header">

                                    <span class="js-menu__close">✕</span>
                                    <h4><?php esc_html_e('Your Cart Items', 'yuno'); ?></h4>
                                    <div class="mini_cart_header_icon">
                                        <i class="<?php echo esc_attr(get_theme_mod('vw_ecommerce_store_cart_icon', 'fas fa-shopping-basket')); ?>"></i>
                                        <span class="screen-reader-text"><?php esc_html_e('shopping cart', 'yuno'); ?></span>
                                        <span class="cart-value"> <?php echo wp_kses_data(WC()->cart->get_cart_contents_count()); ?></span>
                                    </div>

                                </div>

                                <?php
                                if (class_exists('WooCommerce')) :

                                    the_widget('WC_Widget_Cart', 'title=');
                                else :
                                    echo esc_html__("Woo Plugin Not Insall Or Activate", "yuno");
                                endif;
                                ?>

                            </div>
                        </div>


                        <!-- <div class="mini-cart-item">
                   
                    </div> -->

                    <?php else : ?>
                        <span class="cart_no">
                        
                        <div class="mini_cart_btn">
                        <a href="#" class="js-menu__open nav-link" data-menu="#main-nav"><i class="<?php echo esc_attr(get_theme_mod('vw_ecommerce_store_cart_icon', 'fas fa-shopping-basket')); ?>"></i><span class="screen-reader-text"><?php esc_html_e('shopping cart', 'yuno'); ?></span></a>
                           
                            <span class="cart-value"> <?php echo wp_kses_data(WC()->cart->get_cart_contents_count()); ?></span>
                        </div>

                   

                            <!--
                <div class="mini-cart-item">
                    <?php
                        if (class_exists('WooCommerce')) :

                            the_widget('WC_Widget_Cart', 'title=');
                        else :
                            echo esc_html__("Woo Plugin Not Insall Or Activate", "yuno");
                        endif;
                    ?>
                </div> -->
                        </span>
                    <?php endif; ?>

                <?php } ?>
                <!--search-box-->
                <div class="d-flex">
                    <a href="#search-form" data-bs-toggle="collapse" class="nav-link search-btn main-search-btn collapsed" aria-expanded="false"> <i class="fas fa-search"></i> </a>
                    <div class="collapse" id="search-form">
                        <div class="card card-body">
                            <button class="search-tab_1 tab-hiddn-btn"></button>
                            <form action="<?php echo esc_attr(esc_url(home_url('/'))); ?>">
                                <div class="input-group">
                                    <input type="text" class="form-control search-tab_2" placeholder="<?php esc_attr('Search', 'yuno'); ?>" aria-label="<?php esc_attr('Recipient\'s username', 'yuno'); ?>" name="s" id="search" class="form-control" aria-describedby="button-addon2">
                                    <button class="btn btn-theme btn-search" type="submit" id="button-addon2"> <i class="fas fa-search"></i> </button>
                                    <button class="btn btn-search-close search_close_btn" type="button" data-bs-toggle="collapse" data-bs-target="#search-form" aria-expanded="false" aria-controls="collapseExample">
                                        <i class="fas fa-times"></i>
                                    </button>
                                </div>
                            </form>
                            <button class="search-tab_3 tab-hiddn-btn"></button>
                        </div>
                    </div>
                </div>
        <?php
            }

        endif;

        /*-----------------------------------------------------------------------------------------------------------------------*/

        if (!function_exists('yuno_header_navbar_end')) :

            /**
             * header navbar end
             *
             * @since 1.0.0
             */

            function yuno_header_navbar_end()
            {
                echo '</div></nav>';
            }

        endif;

        /*-----------------------------------------------------------------------------------------------------------------------*/

        /**
         * Managed functions for header section hook
         *
         * @since 1.0.0
         */
        add_action('yuno_header_section', 'yuno_top_header_start', 5);
        add_action('yuno_header_section', 'yuno_site_branding', 10);
        add_action('yuno_header_section', 'yuno_header_nav_menu', 15);
        add_action('yuno_header_section', 'yuno_header_search_box', 20);
        add_action('yuno_header_section', 'yuno_header_navbar_end', 25);
