<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package yuno
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function yuno_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

    $site_layout    = yuno_theme_mod_option( 'yuno_site_layout' );
    $page_sidebar   = yuno_theme_mod_option( 'yuno_page_sidebar_layout' );
    $blog_sidebar   = yuno_theme_mod_option( 'yuno_blog_sidebar_layout' );
    $single_sidebar = yuno_theme_mod_option( 'yuno_single_sidebar_layout' );
    $scroll_to_top  = yuno_theme_mod_option( 'yuno_scroll_to_top' );
    $yuno_header    = yuno_theme_mod_option( 'yuno_bead_div_option' );
    $header_trans   = yuno_theme_mod_option( 'yuno_header_bg_option' );

    if ( $yuno_header == 'hide' ) {
        $classes[] = 'no-breadcrumb';
    } else {
        $classes[] = 'show-breadcrumb';
    }

    if ( $header_trans == 'hide' ) {
        $classes[] = 'no-header-transparent';
    } else {
        $classes[] = 'header-transparent';
    }

    if ( is_single() ) {

        if ( $single_sidebar == 'no_sidebar' ) {
            $classes[] = 'no-sidebar full-width-post';
        } elseif ( $single_sidebar == 'left_sidebar' ) {
            $classes[] = 'left-sidebar-post';
        } else {
            $classes[] = 'right-sidebar-post';
        }
        
    } elseif ( is_page() ) {
        if ( $page_sidebar == 'no_sidebar' ) {
            $classes[] = 'no-sidebar full-width-page';
        } elseif ( $page_sidebar == 'left_sidebar' ) {
            $classes[] = 'left-sidebar-page';
        } else {
            $classes[] = 'right-sidebar-page';
        }
    } else {
        if ( $blog_sidebar == 'no_sidebar' ) {
            $classes[] = 'no-sidebar full-width-post';
        } elseif ( $blog_sidebar == 'left_sidebar' ) {
            $classes[] = 'left-sidebar-post';
        } else {
            $classes[] = 'right-sidebar-post';
        }
    }

    if ( wp_is_mobile() ) {
        $classes[] = 'mobile-layout';
    }

    if ( $scroll_to_top == 'show' ) {
        $classes[] = 'show-scroll-to-top';
    } else {
        $classes[] = 'hide-scroll-to-top';
    }

    if ( $site_layout == 'fullwidth_layout' ) {
        $classes[] = 'full-width-layout';
    } elseif ( $site_layout == 'boxed_layout' ) {
        $classes[] = 'boxed boxed-layout';
    } else {
        $classes[] = 'boxed frame-layout';
    }

	return $classes;
}
add_filter( 'body_class', 'yuno_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function yuno_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'yuno_pingback_header' );

/**
 * Enqueue scripts and styles.
 */
function yuno_scripts_assets() {
    wp_enqueue_style( 'yuno-fonts', yuno_fonts_url(), array(), null );
    wp_enqueue_style( 'yuno-style', get_stylesheet_uri(), array(), yuno_THEME_VERSION );
    wp_style_add_data( 'yuno-style', 'rtl', 'replace' );
    wp_enqueue_style( 'fontawesome', get_template_directory_uri() . '/assets/css/font-awesome/css/all.css' );
    wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.css' );
    wp_enqueue_style( 'yuno-woocommerce', get_template_directory_uri() . '/assets/css/woocommerce.css' );
    wp_enqueue_style( 'yuno-main-style', get_template_directory_uri() . '/assets/css/main-style.css' );
    wp_enqueue_style( 'yuno-responsive', get_template_directory_uri() . '/assets/css/responsive.css' );

    wp_enqueue_script( 'bootstrap-js', get_template_directory_uri() . '/assets/js/bootstrap.js', array( 'jquery' ), yuno_THEME_VERSION, true );
    wp_enqueue_script( 'yuno-custom-script', get_template_directory_uri() . '/assets/js/yuno-custom.js', array( 'jquery' ), yuno_THEME_VERSION, true );
    $sticky = yuno_theme_mod_option( 'yuno_menu_sticky_option' );
    wp_localize_script( 'yuno-custom-script', 'ajax_admin', array(
        'sticky_check' => $sticky,
    ));

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }
}
add_action( 'wp_enqueue_scripts', 'yuno_scripts_assets' );

function yuno_admin_scripts() {
    wp_enqueue_style( 'yuno-admin-style', get_template_directory_uri() . '/inc/admin/css/admin.css' );
    wp_enqueue_script( 'yuno-admin-script', get_template_directory_uri() . '/inc/admin/js/admin-script.js', array( 'jquery' ), '', true );
    wp_localize_script( 'yuno-admin-script', 'yuno_ajax_object',
        array( 'ajax_url' => admin_url( 'admin-ajax.php' ) )
    );
}
add_action( 'admin_enqueue_scripts', 'yuno_admin_scripts' );

/**
 * Styles the header image and custom css.
 *
 * @see yuno_custom_style().
 */
function yuno_custom_style() {

    $header_text_color  = get_header_textcolor();
    $header_image       = get_header_image();
    $custom_css         = "";
    $fwidget_color      = yuno_theme_mod_option( 'yuno_fwidget_text_color' );
    $copyright_color    = yuno_theme_mod_option( 'yuno_copyright_text_color' );
    $theme_color        = yuno_theme_mod_option( 'yuno_theme_color' );
    $link_color         = yuno_theme_mod_option( 'yuno_link_color' );
    $btn_color          = yuno_theme_mod_option( 'yuno_btn_color' );
    $btn_border_color   = yuno_theme_mod_option( 'yuno_btn_border_color' );
    $btn_hover_color    = yuno_theme_mod_option( 'yuno_btn_hover_color' );
    $hover_border_color = yuno_theme_mod_option( 'yuno_btn_hover_border_color' );

    // If we get this far, we have custom styles. Let's do this.
    wp_enqueue_style( 'yuno-inline-style', get_template_directory_uri().'/assets/css/yuno-inline-style.css', array(), yuno_THEME_VERSION );

    if ( has_header_image() ) : 

        $custom_css .= ".header-wrapper{
            background: linear-gradient(to bottom, rgb(0 0 0 / 25%) 0%, rgb(0 0 0 / 25%) 59%, rgb(0 0 0 / 25%) 100%), url( ".esc_attr( $header_image )." ) no-repeat;
            background-size: cover;
            background-repeat: no-repeat;
        }";

    endif; 

	$custom_css .= ".site-title a,
    .site-description {
        color: #".esc_attr( $header_text_color ).";
    }
    .main-navigation li>a {
        color: #".esc_attr( $header_text_color ).";
    }";

    if ( ! empty ( $theme_color ) ) {
        $custom_css .= ":root {
            --yuno-primary: ".esc_attr( $theme_color ).";
        }";
    }

    if ( ! empty ( $link_color ) ) {
        $custom_css .= ".posted-on a, .entry-footer a, .site-info a, .author.vcard a {
            color: ".esc_attr( $link_color )."!important;
        }";
    }

    if ( ! empty ( $btn_color ) ) {
        $custom_css .= ".btn-yuno-button {
            background-color: ".esc_attr( $btn_color ).";
        }
        .search-form .search-submit {
            background-color: ".esc_attr( $btn_color ).";
        }
        span.page-numbers.current {
            background: ".esc_attr( $btn_color ).";
        }
        .comment-body a.comment-reply-link, #commentform input#submit {
            background-color: ".esc_attr( $btn_color ).";
        }";
    }

    if ( ! empty ( $btn_border_color ) ) {
        $custom_css .= ".btn-yuno-button {
            border: 1px solid ".esc_attr( $btn_border_color ).";
        }
        .navigation.pagination .page-numbers {
            border: 1px solid ".esc_attr( $btn_border_color ).";
        }
        .comment-body a.comment-reply-link, #commentform input#submit {
            border: 1px solid ".esc_attr( $btn_border_color ).";
        }";
    }

    if ( ! empty ( $btn_hover_color ) ) {
        $custom_css .= "
        .btn-yuno-button:hover {
            background-color: ".esc_attr( $btn_hover_color ).";
        }
        .navigation.pagination .page-numbers:hover {
            background: ".esc_attr( $btn_hover_color ).";
        }
        .comment-body a.comment-reply-link:hover {
            background-color: ".esc_attr( $btn_hover_color ).";
        }";
    }

    if ( ! empty ( $hover_border_color ) ) {
        $custom_css .= "
        .btn-yuno-button:hover {
            border: 1px solid ".esc_attr( $hover_border_color ).";
        }
        .comment-body a.comment-reply-link:hover {
            border: 1px solid ".esc_attr( $hover_border_color ).";
        }";
    }

    if ( ! empty ( $fwidget_color ) ) {
        $custom_css .= ".site-footer {
            background-color: ".esc_attr( $fwidget_color ).";
        }";
    }

    if ( ! empty ( $copyright_color ) ) {
        $custom_css .= ".site-info {
            background-color: ".esc_attr( $copyright_color ).";
        }";
    }

    wp_add_inline_style( 'yuno-inline-style', $custom_css ); 
}
add_action( 'wp_enqueue_scripts', 'yuno_custom_style' );

/**
 * Excerpt length
 * 
 * @since yuno 1.0.0
 * @return Excerpt length
 */
function yuno_excerpt_length( $length ){
    if ( is_admin() ) {
        return $length;
    }

    $length = yuno_theme_mod_option( 'yuno_blog_excerpt_length' );
    return $length;
}
add_filter( 'excerpt_length', 'yuno_excerpt_length', 999 );

/**
 * Comment Form field position
 */
function yuno_comment_field_to_bottom( $fields ) {
    $comment_field = $fields['comment'];
    unset( $fields['comment'] );
    $fields['comment'] = $comment_field;
    return $fields;
}
add_filter( 'comment_form_fields', 'yuno_comment_field_to_bottom' );

/**
* Default comment form includes name, email address and website URL
* Default comment form elements are hidden when user is logged in
*/
add_filter( 'comment_form_default_fields', 'yuno_comment_custom_fields' );
function yuno_comment_custom_fields( $fields ) {

    $commenter = wp_get_current_commenter();
    $req       = get_option( 'require_name_email' );
    $aria_req  = ( $req ? " aria-required='true'" : ’ );

    $fields[ 'author' ] = '<div class="comment-form-author">
                                <div class="form-group">
                                    <input type="text" class="form-control" id="author" placeholder="' . esc_attr__( 'Name*', 'yuno' ) . '" name="author" value="'. esc_attr( $commenter['comment_author'] ) .
                                    '"' . $aria_req . '>
                                    <span class="form-icon fa fa-user"></span>
                                </div>
                            </div>';

    $fields[ 'email' ] = '<div class="comment-form-email">
                                <div class="form-group">
                                    <input class="form-control" type="text" id="email" placeholder="' . esc_attr__( 'Email*', 'yuno' ) . '" name="email" value="'. esc_attr( $commenter['comment_author_email'] ) .
                                    '" ' . $aria_req . '>
                                    <span class="form-icon fas fa-envelope"></span>
                                </div>
                            </div>';

    $fields[ 'url' ] = '<div class="comment-form-url">
                            <div class="form-group">
                                <input id="url" class="form-control" type="text" placeholder="' . esc_attr__( 'Website', 'yuno' ) . '" name="url" value="'. esc_attr( $commenter['comment_author_url'] ) .
                                '" ' . $aria_req . '>
                                <span class="form-icon fas fa-wifi"></span>
                            </div>
                        </div>';
  return $fields;
}

/**
 * Fix skip link focus in IE11.
 *
 * This does not enqueue the script because it is tiny and because it is only for IE11,
 * thus it does not warrant having an entire dedicated blocking script being loaded.
 *
 * @link https://git.io/vWdr2
 */
function yuno_skip_link_focus_fix() {
    // The following is minified via `terser --compress --mangle -- js/skip-link-focus-fix.js`.
    ?>
    <script>
    /(trident|msie)/i.test(navigator.userAgent)&&document.getElementById&&window.addEventListener&&window.addEventListener("hashchange",function(){var t,e=location.hash.substring(1);/^[A-z0-9_-]+$/.test(e)&&(t=document.getElementById(e))&&(/^(?:a|select|input|button|textarea)$/i.test(t.tagName)||(t.tabIndex=-1),t.focus())},!1);
    </script>
    <?php
}
add_action( 'wp_print_footer_scripts', 'yuno_skip_link_focus_fix' );